FlipClock class

FlipClock display with current time.

Display a row of FlipWidget to show the current time digits, this digits are refreshed by a stream of DateTime.now() instances. Since FlipWidget animates only changes, just digits that actually change between seconds are flipped.

Inheritance

Constructors

FlipClock({Key? key, required double digitSize, required double width, required double height, AxisDirection flipDirection = AxisDirection.down, bool showSeconds = true, Curve? flipCurve, Color? digitColor, Color? backgroundColor, double? separatorWidth, Color? separatorColor, Color? separatorBackgroundColor, bool? showBorder, double? borderWidth, Color? borderColor, BorderRadius borderRadius = const BorderRadius.all(Radius.circular(4.0)), double hingeWidth = 0.8, double? hingeLength, Color? hingeColor, EdgeInsets digitSpacing = const EdgeInsets.symmetric(horizontal: 2.0)})
FlipClock constructor.

Properties

hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showSeconds → bool
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited