FlipWidget<T> class

FliWidget animates the display of items through flip animations.

Depending on the flipType parameter it will animate diferently:

  • with middleFlip type it resembles a single Mechanical Flip Board display element.
  • with spinFlip type it animates as a regular roll flip.

It is usually used to flip letters, digits and images but can actually be used to flip any widget change.

Inheritance

Constructors

FlipWidget({Key? key, required FlipType flipType, required Stream<T> itemStream, required ItemBuilder<T> itemBuilder, required AxisDirection flipDirection, T? initialValue, Duration flipDuration = const Duration(milliseconds: 800), Curve flipCurve = Curves.easeInOut, double hingeWidth = 0.0, double hingeLength = 0.0, Color? hingeColor, double perspectiveEffect = 0.006, VoidCallback? onDone, int startCount = 0})
FlipWidget constructor.
const

Properties

axis → Axis
Axis of my flipDirection.
no setter
flipCurve → Curve
Curve for the flip animation.
final
flipDirection → AxisDirection
Direction of the flip animation.
final
flipDuration → Duration
Duration of the flip animation.
final
flipType → FlipType
Defines the type of animation.
final
hashCode → int
The hash code for this object.
no setterinherited
hingeColor → Color?
Color of the middle hinge element.
final
hingeLength → double
Length of the middle hinge element.
final
hingeWidth → double
Width of the middle hinge element.
final
initialValue → T?
Optional initial value to be displayed before the first animation.
final
itemBuilder → ItemBuilder<T>
Builder to construct widgets out of stream items.
final
itemStream → Stream<T>
Stream of items that will be built and flipped into view.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onDone → VoidCallback?
Optional callback for onDone stream event.
final
perspectiveEffect → double
Perspective effect for the Transform Matrix4.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startCount → int
Widget state count flag.
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<FlipWidget<T>>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

bounceFastFlip → const _BounceFastFlipCurve
Custom animation Curve for a fast bounce effect (bang! effect).
bounceSlowFlip → const _BounceSlowFlipCurve
Custom animation animation for a slow bounce effect (slow bang! effect).
defaultFlip → const Cubic
Default animation Curve.